@@ -3,7 +3,7 @@ BEGIN {
   $App::DuckPAN::Web::AUTHORITY = 'cpan:GETTY';
 }
 {
-  $App::DuckPAN::Web::VERSION = '0.037';
+  $App::DuckPAN::Web::VERSION = '0.038';
 }
 
 use Moo;
@@ -16,6 +16,7 @@ use Data::Printer;
 use IO::All -utf8;
 use HTTP::Request;
 use LWP::UserAgent;
+use URI::Escape;
 
 has blocks => ( is => 'ro', required => 1 );
 has page_root => ( is => 'ro', required => 1 );
@@ -124,7 +125,10 @@ sub request {
 			last if $result;
 		}
 		my $page = $self->page_spice;
+		my $uri_encoded_query = uri_escape($query);
+		my $uri_encoded_ddh = uri_escape('duckduckhack-template-for-spice');
 		$page =~ s/duckduckhack-template-for-spice/$query/g;
+		$page =~ s/$uri_encoded_ddh/$uri_encoded_query/g;
 		if ($result) {
 			p($result);
             my $call_extf = $result->caller->module_share_dir.'/spice.js';
@@ -179,7 +183,7 @@ App::DuckPAN::Web
 
 =head1 VERSION
 
-version 0.037
+version 0.038
 
 =head1 AUTHOR
 
